@@ -240,15 +240,18 @@ void create_context_menu (GdkEventButton *event)
             // Icon
             if (streq_any (ks.txt_fields[TYPE_TXT], "menu", "pipe menu", "item", NULL)) {
                 if (STREQ (ks.txt_fields[TYPE_TXT], "item")) {
+                    // Translation note: If the target language distinguishes between definite and indefinite forms, please use the indefinite form (“Icon”), not the definite one (“The Icon”).
                     create_cm_headline (context_menu, _(" Icon")); // Items have "Icon" and "Action" as context menu headlines.
                 }
 
-                menu_item = gtk_menu_item_new_with_label ((ks.txt_fields[ICON_PATH_TXT]) ? _("Change Icon") : 
-                                                                                           // Translation note: This is for a context menu
+                menu_item = gtk_menu_item_new_with_label ((ks.txt_fields[ICON_PATH_TXT]) ? // Translation note: This is for a context menu. If the target language distinguishes between definite and indefinite forms, please use the indefinite form (“Icon), not the definite one (“The Icon”).
+                                                                                           _("Change Icon") : 
+                                                                                           // Translation note: This is for a context menu. If the target language distinguishes between definite and indefinite forms, please use the indefinite form (“Icon”), not the definite one (“The Icon”).
                                                                                            C_("Context Menu|Menu or Item", "Add Icon"));
                 g_signal_connect (menu_item, "activate", G_CALLBACK (icon_choosing_by_button_or_context_menu), NULL);
                 gtk_menu_shell_append (GTK_MENU_SHELL (context_menu), menu_item);
                 if (ks.txt_fields[ICON_PATH_TXT]) {
+                    // Translation note: If the target language distinguishes between definite and indefinite forms, please use the indefinite form (“Icon”), not the definite one (“The Icon”).
                     menu_item = gtk_menu_item_new_with_label (_("Remove Icon"));
                     g_signal_connect (menu_item, "activate", G_CALLBACK (remove_icons_from_menus_or_items), GUINT_TO_POINTER (TRUE));
                     gtk_menu_shell_append (GTK_MENU_SHELL (context_menu), menu_item);
@@ -364,6 +367,7 @@ void create_context_menu (GdkEventButton *event)
             // Actions
             if (streq_any (ks.txt_fields[TYPE_TXT], "item", "action", NULL)) {
                 if (STREQ (ks.txt_fields[TYPE_TXT], "item") || not_all_options_of_selected_action_set) {
+                    // Translation note: If the target language distinguishes between definite and indefinite forms, please use the indefinite form (“Actions”), not the definite one (“The Actions”).
                     create_cm_headline (context_menu, _(" Actions"));
                 }
 
@@ -402,15 +406,22 @@ void create_context_menu (GdkEventButton *event)
     */
     if (!path || ks.txt_fields[ELEMENT_VISIBILITY_TXT]) {
         const gchar *basic_menu_elements[] = { "menu", "pipe menu", "item", "separator" };
-        const gchar *add_basic_menu_elements_for_cm[] = { // Translation note: This is for a context menu.
+        const gchar *add_basic_menu_elements_for_cm[] = { // Translation note: This is for a context menu. If the target language distinguishes between definite and indefinite forms, please use the indefinite form (“Menu”), not the definite one (“The Menu”).
 		                                                  N_("Add Menu"), 
-														  // Translation note: This is for a context menu.
+														  // Translation note: This is for a context menu. If the target language distinguishes between definite and indefinite forms, please use the indefinite form (“Pipe Menu”), not the definite one (“The Pipe Menu”).
 														  N_("Add Pipe Menu"), 
-														  // Translation note: This is for a context menu.
+														  // Translation note: This is for a context menu. If the target language distinguishes between definite and indefinite forms, please use the indefinite form (“Item”), not the definite one (“The Item”).
 														  N_("Add Item"), 
-														  // Translation note: This is for a context menu.
+														  // Translation note: This is for a context menu. If the target language distinguishes between definite and indefinite forms, please use the indefinite form (“Separator”), not the definite one (“The Separator”).
 														  N_("Add Separator") };
-        const gchar *basic_menu_elements_for_cm[] = { N_("Menu"), N_("Pipe Menu"), N_("Item"), N_("Separator") };
+        const gchar *basic_menu_elements_for_cm[] = { // Translation note: If the target language distinguishes between definite and indefinite forms, please use the indefinite form (“Menu”), not the definite one (“The Menu”).
+                                                      N_("Menu"), 
+                                                      // Translation note: If the target language distinguishes between definite and indefinite forms, please use the indefinite form (“Pipe Menu”), not the definite one (“The Pipe Menu”).
+                                                      N_("Pipe Menu"), 
+                                                      // Translation note: If the target language distinguishes between definite and indefinite forms, please use the indefinite form (“Item”), not the definite one (“The Item”).
+                                                      N_("Item"), 
+                                                      // Translation note: If the target language distinguishes between definite and indefinite forms, please use the indefinite form (“Separator”), not the definite one (“The Separator”).
+                                                      N_("Separator") };
         const gchar *items[] = { "item+Execute", "item+Exit", "item+Reconfigure", "item+Restart", "item+SessionLogout" };
         enum { MENU, PIPE_MENU, ITEM, SEPARATOR };
         const guint8 number_of_basic_menu_elements = G_N_ELEMENTS (basic_menu_elements);
