@@ -272,6 +272,7 @@ void row_selected (void)
             gtk_widget_show (ks.new_action_option_widgets[ACTION_OPTION_DONE]);
             gtk_widget_show (ks.new_action_option_widgets[ACTION_OPTION_CANCEL]);
             gtk_widget_show (ks.remove_icon);
+            // Translation note: If the target language distinguishes between definite and indefinite forms, please use the indefinite form (“Menu ID”), not the definite one (“The Menu ID”).
             gtk_label_set_markup (GTK_LABEL (ks.entry_labels[MENU_ID_ENTRY]), _(" Menu ID: "));
             gtk_widget_hide (ks.mandatory);
             gtk_label_set_markup (GTK_LABEL (ks.mandatory), ks.mandatory_label_txt->str);
@@ -581,6 +582,7 @@ void row_selected (void)
     // Item selected?
     if (STREQ (ks.txt_fields[TYPE_TXT], "item")) {
         gtk_widget_show (ks.bt_add[ACTION_OR_OPTION]);
+        // Translation note: If the target language distinguishes between definite and indefinite forms, please use the indefinite form (“Action”), not the definite one (“The Action”).
         gtk_label_set_text_with_mnemonic (GTK_LABEL (ks.bt_add_action_option_label), _("_Action"));
     }
 
@@ -605,7 +607,10 @@ void row_selected (void)
                                                ((STREQ (ks.txt_fields[MENU_ELEMENT_TXT], "Execute") &&
                                                number_of_children_of_iter < NUMBER_OF_EXECUTE_OPTS) || 
                                                number_of_children_of_iter == 0)) ? 
-                                              _("_Action/Option") : _("_Action"));
+                                              // Translation note: If the target language distinguishes between definite and indefinite forms, please use the indefinite form (“Action/Option”), not the definite one (“The Action/The Option”).
+                                              _("_Action/Option") : 
+                                              // Translation note: If the target language distinguishes between definite and indefinite forms, please use the indefinite form (“Action”), not the definite one (“The Action”).
+                                              _("_Action"));
         }
 
         // "prompt" or "command" option selected and action is "Execute"?
@@ -801,6 +806,7 @@ void set_entry_fields (void)
     gtk_widget_show (ks.entry_grid);
 
     // Default settings
+    // Translation note: If the target language distinguishes between definite and indefinite forms, please use the indefinite form (“Label”), not the definite one (“The Label”).
     gtk_label_set_text (GTK_LABEL (ks.entry_labels[MENU_ELEMENT_OR_VALUE_ENTRY]), _(" Label: "));
 
     g_autofree gchar *execute_label_text = g_strdup_printf  ("%s Execute: ", right_to_left);
